summaryrefslogtreecommitdiffstats
path: root/kexi/widget/utils/kexiflowlayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/utils/kexiflowlayout.h')
-rw-r--r--kexi/widget/utils/kexiflowlayout.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/widget/utils/kexiflowlayout.h b/kexi/widget/utils/kexiflowlayout.h
index fa48df6f5..4ac7450c2 100644
--- a/kexi/widget/utils/kexiflowlayout.h
+++ b/kexi/widget/utils/kexiflowlayout.h
@@ -37,11 +37,11 @@ class KEXIGUIUTILS_EXPORT KexiFlowLayout : public TQLayout
ie as it is stored in m_list. You must delete the list after using it. */
TQPtrList<TQWidget>* widgetList() const;
- /*! Sets layout's orientation to \a orientation. Default orientation is Qt::Vertical. */
- void setOrientation(Qt::Orientation orientation) { m_orientation = orientation; }
+ /*! Sets layout's orientation to \a orientation. Default orientation is TQt::Vertical. */
+ void setOrientation(TQt::Orientation orientation) { m_orientation = orientation; }
/*! \return layout's orientation. */
- Qt::Orientation orientation() const { return m_orientation; }
+ TQt::Orientation orientation() const { return m_orientation; }
void setJustified(bool justify) { m_justify = justify; }
bool isJustified() const { return m_justify; }
@@ -70,7 +70,7 @@ class KEXIGUIUTILS_EXPORT KexiFlowLayout : public TQLayout
int m_cached_width;
int m_cached_hfw;
bool m_justify;
- Qt::Orientation m_orientation;
+ TQt::Orientation m_orientation;
TQSize m_cached_sizeHint;
TQSize m_cached_minSize;
};